==> flutter_catalogue_widgets-0.0.6.tar.gz: lib/custom-linearProgressIndicator.dart <==
/*
Description:
A loader or progress bar that can be used to indicate the completeness of something or act as a splash/wait page or element.
There are two types of Linear Progress Bars: Definite and Indefinite
- Indefinite progress bars are indefinitely moving bars that can be used to showcase progress without any particular values.
- Defintie progress bars intake a value and show the progress accordingly. For example, 0.6 will show a bar that is 60% complete.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-linearProgressIndicator.dart';

Usage:
- Defining the Linear Progress Bar object
  (Please Note: value = 0 or value = null will create an indefinte Linear Progress bar)

    CustomLinearProgressBarParameters linearBarParameters =
        new CustomLinearProgressBarParameters(
            value: 0,
            backgroundColor: Colors.red,
            valueColor: AlwaysStoppedAnimation<Color>(Colors.white));
    CustomLinearProgressBarIndicator(linearBarParameters);

- Object call for the widget

    CustomLinearProgressBarIndicator(linearBarParameters)

Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'theme.dart';
import 'widget-classesUsed.dart';
import 'consts.dart' as cons;

Widget CustomLinearProgressBarIndicator(
    CustomLinearProgressBarParameters linearBarParams) {
  // If no parameters are passed as a part of the widget call
  if (linearBarParams == null) {
    return Container(
      padding: cons.edgeInsetValues,
      child: LinearProgressIndicator(
        value: cons.intialValue,
        backgroundColor: MediumGreyThemeData().backgroundColor,
        valueColor: new AlwaysStoppedAnimation<Color>(
            MediumGreyThemeData().accentColor),
      ),
    );
  } else {
    // If all or limited parameters are passed as part of the parameters
    return Container(
      padding: cons.edgeInsetValues,
      child: LinearProgressIndicator(
        value: (linearBarParams.value == 0 || linearBarParams.value == null)
            ? null
            : linearBarParams
                .value, // If value is null or 0, the bar is non-definite, else it will take the value
        backgroundColor: (linearBarParams.backgroundColor != null)
            ? linearBarParams.backgroundColor
            : MediumGreyThemeData().backgroundColor,
        valueColor: (linearBarParams.valueColor != null)
            ? linearBarParams.valueColor
            : new AlwaysStoppedAnimation<Color>(
                MediumGreyThemeData().accentColor),
        semanticsLabel: (linearBarParams.semanticsLabel != null)
            ? linearBarParams.semanticsLabel
            : "Progress Bar",
      ),
    );
  }
}

==> flutter_catalogue_widgets-0.0.14.tar.gz: lib/custom-linearProgressIndicator.dart <==
/*
Description:
A loader or progress bar that can be used to indicate the completeness of something or act as a splash/wait page or element.
There are two types of Linear Progress Bars: Definite and Indefinite
- Indefinite progress bars are indefinitely moving bars that can be used to showcase progress without any particular values.
- Defintie progress bars intake a value and show the progress accordingly. For example, 0.6 will show a bar that is 60% complete.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-linearProgressIndicator.dart';

Usage:
- Defining the Linear Progress Bar object
  (Please Note: value = 0 or value = null will create an indefinte Linear Progress bar)

    CustomLinearProgressBarParameters linearBarParameters =
        new CustomLinearProgressBarParameters(
            value: 0,
            backgroundColor: Colors.red,
            valueColor: AlwaysStoppedAnimation<Color>(Colors.white));
    customLinearProgressBarIndicator(linearBarParameters);

- Object call for the widget

    customLinearProgressBarIndicator(linearBarParameters)

Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'theme.dart';
import 'widget-classesUsed.dart';
import 'consts.dart' as cons;

Widget customLinearProgressBarIndicator(
    CustomLinearProgressBarParameters linearBarparams) {
  // If no parameters are passed as a part of the widget call
  if (linearBarparams == null) {
    return Container(
      padding: cons.edgeInsetValues,
      child: LinearProgressIndicator(
        value: cons.intialValue,
        backgroundColor: mediumGreyThemeData().backgroundColor,
        valueColor: new AlwaysStoppedAnimation<Color>(
            mediumGreyThemeData().accentColor),
      ),
    );
  } else {
    // If all or limited parameters are passed as part of the parameters
    return Container(
      padding: cons.edgeInsetValues,
      child: LinearProgressIndicator(
        value: (linearBarparams.value == 0 || linearBarparams.value == null)
            ? null
            : linearBarparams
                .value, // If value is null or 0, the bar is non-definite, else it will take the value
        backgroundColor: (linearBarparams.backgroundColor != null)
            ? linearBarparams.backgroundColor
            : mediumGreyThemeData().backgroundColor,
        valueColor: (linearBarparams.valueColor != null)
            ? linearBarparams.valueColor
            : new AlwaysStoppedAnimation<Color>(
                mediumGreyThemeData().accentColor),
        semanticsLabel: (linearBarparams.semanticsLabel != null)
            ? linearBarparams.semanticsLabel
            : "Progress Bar",
      ),
    );
  }
}
